@@ -2,6 +2,7 @@ from __future__ import absolute_import
 from __future__ import unicode_literals
 
 import requests
+from requests.adapters import HTTPAdapter
 from requests.auth import HTTPBasicAuth
 from laipvt.interface.middlewareinterface import MiddlewareInterface
 from laipvt.handler.confighandler import CheckResultHandler
@@ -77,13 +78,16 @@ class HarborController(MiddlewareInterface):
 
     def _check(self):
         super().wait_for_service_start()
+        s = requests.Session()
+        s.mount('http://', HTTPAdapter(max_retries=3))
+        s.mount('https://', HTTPAdapter(max_retries=3))
         try:
             for i in self.harbor_server:
                 url = "http://{IP}:{PORT}/api/v2.0/health".format(
                     IP=i.ipaddress, PORT=self.harbor_cfg["harbor"]["http_port"]
                 )
                 log.info("检查 {}:{} 上的 Harbor 健康性".format(i.ipaddress, self.harbor_cfg["harbor"]["http_port"]))
-                result = requests.get(url).json()
+                result = s.get(url, timeout=5).json()
                 if result["status"] == "healthy":
                     log.info("Harbor 服务运行正常")
                 else:
@@ -93,6 +97,7 @@ class HarborController(MiddlewareInterface):
         except Exception as e:
             log.error(e)
             log.error("{IP} 上的 Harbor 服务异常".format(IP=self.harbor_cfg["harbor"]["ipaddress"]))
+            exit(2)
 
     def _change_password(self):
         log.info("修改 Harbor 登陆密码")
@@ -119,4 +124,4 @@ class HarborController(MiddlewareInterface):
         self._chmod_data()
         self._start()
         self._check()
-        self._change_password()
+        self._change_password()
\ No newline at end of file
