@@ -163,7 +163,7 @@ class MysqlController(MiddlewareInterface):
     def run_backup_crontab(self):
         log.info("配置Mysql 备份定时任务")
         self.crontab_task = "01 00 * * * sudo docker run --rm  " \
-                            "-v {}:/mysql-backup  -v {}:/mysql_test/mysql/data/mysql" \
+                            "-v {}:/mysql-backup  -v {}:/var/lib/mysql" \
                             " -v {}:/backup.sh -v {}:/backup.conf  {}:{}/middleware/mysql_xtrabackup:5.7.32 /bin/bash "\
                             "-c '/backup.sh /backup.conf /mysql-backup/backup.log &>> /mysql-backup/backup.log'"
         self.crontab_task = self.crontab_task.format(
