@@ -2,7 +2,7 @@ from __future__ import absolute_import
 from __future__ import unicode_literals
 
 from laipvt.interface.serviceinterface import ServiceInterface
-from laipvt.sysutil.util import path_join, log, status_me
+from laipvt.sysutil.util import path_join, status_me
 
 
 class CaptchaController(ServiceInterface):
