@@ -21,70 +21,23 @@ class CommanderController(ServiceInterface):
         self.nginx_template = path_join(self.templates_dir, "nginx/http/nginx-commander.tmpl")
         self.nginx_tmp = path_join("/tmp", "nginx-commander.conf")
         self.nginx_file_remote = path_join(self.deploy_dir, "nginx/http/nginx-commander.conf")
-        self.minio_data_list = [
-            path_join(self.data_dir, "mage_minio_data"),
-            path_join(self.data_dir, "siber_minio_data")
-        ]
-
-    @status_me("mage")
-    def init_minio_data(self):
-        # minio_cfg = MinioConfigHandler().get_config_with_check_result()
-        try:
-            for bucket in self.service_info.buckets:
-                # print(bucket)
-                try:
-                    endpoint = "{}:{}".format(self.middleware_cfg.minio.lb, self.middleware_cfg.minio.nginx_proxy_port)
-                    cli = Minio(
-                        endpoint,
-                        self.middleware_cfg.minio.username,
-                        self.middleware_cfg.minio.password,
-                        secure=False
-                    )
-                    if not cli.bucket_exists(bucket):
-                        cli.make_bucket(bucket)
-                    content_types = {
-                        'txt': 'text/plain',
-                        'jpg': 'image/jpg',
-                        'gif': 'image/gif',
-                        'png': 'image/png',
-                        'jpeg': 'image/jpeg',
-                        'pdf': 'application/pdf',
-                        'tif': 'image/tiff',
-                        'bmp': 'image/bmp',
-                        'xlsx': 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'
-                    }
-                    for data_dir in self.minio_data_list:
-                        for i in os.listdir(data_dir):
-                            image_name = path_join(data_dir, i)
-                            file_type = content_types[i.split('.')[-1]]
-                            cli.fput_object(bucket, i, image_name, content_type=file_type)
-                            if i.split('.')[-1] == "xlsx":
-                                cli.fput_object(bucket, "document-mining-backend/" + i,  image_name, content_type=file_type)
-
-                except Exception as e:
-                    log.error(e)
-                    log.error("Minio上传数据失败")
-                    exit(2)
-        except Exception as e:
-            log.error(e)
-            log.error("创建bucket失败")
-            exit(2)
 
     @status_me("commander")
     def init_commander_mysql(self):
         sql_path = self.service_path.sqls
         log.info(sql_path)
         db_info = walk_sql_path(sql_path)
-        sql = SqlModule(host=self.master_host, port=self.middleware_cfg.mysql.port,
+        sql = SqlModule(host=self.middleware_cfg.mysql.ipaddress[0], port=int(self.middleware_cfg.mysql.port),
                         user=self.middleware_cfg.mysql.username, passwd=self.middleware_cfg.mysql.password)
         for db_name, sql_files in db_info.items():
             create_db = "create database If Not Exists {db_name} DEFAULT CHARSET utf8mb4 COLLATE utf8mb4_general_ci".format(
                 db_name=db_name
             )
             sql.insert_sql(create_db)
-            sql.use_db(db_name)
-            for sql_file in sql_files:
-                sql.import_from_file_commander(sql_file, file_eof=";")
+            sql.import_from_dir(db_name, path_join(sql_path, db_name))
+            #sql.use_db(db_name)
+            #for sql_file in sql_files:
+            #    sql.import_from_file_commander(sql_file, file_eof=";")
 
     @status_me("commander")
     def push_commander_images(self):
@@ -156,9 +109,11 @@ class CommanderController(ServiceInterface):
     @status_me("commander")
     def init_minio_data(self):
         for bucket in self.service_info.buckets:
-            # print(bucket)
             try:
-                endpoint = "{}:{}".format(self.middleware_cfg.minio.lb, self.middleware_cfg.minio.nginx_proxy_port)
+                if self.middleware_cfg.minio.is_deploy:
+                    endpoint = "{}:{}".format(self.middleware_cfg.minio.lb, self.middleware_cfg.minio.nginx_proxy_port)
+                else:
+                    endpoint = "{}:{}".format(self.middleware_cfg.minio.ipaddress[0], self.middleware_cfg.minio.port)
                 cli = Minio(
                     endpoint,
                     self.middleware_cfg.minio.username,
