@@ -1,14 +1,10 @@
 from __future__ import absolute_import
 from __future__ import unicode_literals
 
-import os
-from minio import Minio
-from laipvt.helper.exception import UtilsError
 from laipvt.interface.serviceinterface import ServiceInterface
-from laipvt.handler.confighandler import CheckResultHandler, ServiceConfigHandler
-from laipvt.sysutil.template import FileTemplate
+from laipvt.handler.middlewarehandler import EtcdConfigHandler
 from laipvt.sysutil.util import path_join, log, status_me
-from laipvt.handler.middlewarehandler import MinioConfigHandler
+from laipvt.controller.middleware.etcd import EtcdController
 
 
 class LicenseController(ServiceInterface):
@@ -30,7 +26,9 @@ class LicenseController(ServiceInterface):
             self._exec_command_to_host(cmd="mkdir -p {}".format(data_path), server=server)
             self._send_file(src=lcs_file_path, dest=path_join(data_path, "license.lcs"))
 
-    def restart_license_service(self):
+    def restart_service(self):
+        etcd = EtcdController(self.check_result, EtcdConfigHandler(), "")
+        etcd.reset()
         get_pod_info_cmd = "kubectl -n mid get pod |grep license-manager"
         res = self._exec_command_to_host(cmd=get_pod_info_cmd, server=self.harbor_hosts[0], check_res=True)
         if not (res["code"] == 0 and "Running" in res["stdout"]):
@@ -39,6 +37,12 @@ class LicenseController(ServiceInterface):
         restart_deployment_cmd = "kubectl -n mid rollout restart deployment license-manager"
         self._exec_command_to_host(cmd=restart_deployment_cmd, server=self.harbor_hosts[0], check_res=True)
 
+        restart_all_deployment_cmd = [
+            "kubectl -n mage rollout restart deployment",
+            "kubectl -n rpa rollout restart deployment"
+        ]
+        self._exec_command_to_host(cmd=restart_all_deployment_cmd, server=self.harbor_hosts[0], check_res=True)
+
     @status_me("middleware")
     def deploy_license(self):
         self._create_namespace(
@@ -51,4 +55,4 @@ class LicenseController(ServiceInterface):
 
     def renew_license(self, license_file):
         self._prepare_license_data_file(is_renew=True, license_file=license_file)
-        self.restart_license_service()
\ No newline at end of file
+        self.restart_service()
