@@ -54,6 +54,7 @@ class OcrController(MiddlewareInterface):
         data["name"] = module_name
         data["image_name"] = path_join(self.registry_hub, self.project, module_name)
         data["port"] = self.handler.get_ocr_module_port(module_name)
+        log.info("获取{}的端口号为{}".format(data['name'], data['port']))
         data["machine_type"] = "gpu" if self.service_path.config.require_tfserver else "cpu"
         return data
 
@@ -87,6 +88,26 @@ class OcrController(MiddlewareInterface):
             log.info("开始部署ocr 模型 {}".format(module))
             self.deploy(server, compose_file, compose_file_remote)
 
+    def restart_ocr_module(self):
+        server = self.servers.get_role_obj("licserver")[0]
+        for module in self.deploy_service_list:
+            compose_file_remote = path_join(self.check_result.deploy_dir, module, "docker-compose.yaml")
+            compose_cmd = ComposeModel(compose_file_remote)
+            ssh_cli = ssh_obj(ip=server.ipaddress, user=server.username,
+                              password=server.password, port=server.port)
+            try:
+                log.info("重新启动服务{}".format(compose_cmd.restart()))
+                ssh_cli.run_cmd(compose_cmd.restart())
+            except Exception as e:
+                log.error(e)
+                exit(2)
+            finally:
+                ssh_cli.close()
+
+    def renew_license(self, license_file):
+        self.start_licserver(renew=True, license_file=license_file)
+        self.restart_ocr_module()
+
     def run(self):
         self.push_images()
         self.start_licserver()
