@@ -1,14 +1,8 @@
 from __future__ import absolute_import
 from __future__ import unicode_literals
 
-import os
-from minio import Minio
-from laipvt.helper.exception import UtilsError
 from laipvt.interface.serviceinterface import ServiceInterface
-from laipvt.handler.confighandler import CheckResultHandler, ServiceConfigHandler
-from laipvt.sysutil.template import FileTemplate
-from laipvt.sysutil.util import path_join, log, status_me
-from laipvt.handler.middlewarehandler import MinioConfigHandler
+from laipvt.sysutil.util import path_join
 
 
 class OcrStandardController(ServiceInterface):
