@@ -134,6 +134,24 @@ class MiddlewareInterface():
             finally:
                 ssh_cli.close()
 
+    def reset(self):
+        compose_cmd = ComposeModel(self.docker_compose_file)
+        for server in self.master_server:
+            log.info("重新加载 %s %s服务" % (server.ipaddress, self.middleware_name))
+            ssh_cli = ssh_obj(ip=server.ipaddress, user=server.username, password=server.password, port=server.port)
+            try:
+                res = ssh_cli.run_cmd(compose_cmd.down())
+                res = ssh_cli.run_cmd(compose_cmd.up())
+                if res["code"] != 0:
+                    log.error("重启 %s: %s服务失败.错误原因: %s %s" % (
+                    server.ipaddress, self.middleware_name, res["stderr"], res["stdout"]))
+                    exit(2)
+            except Exception as e:
+                log.error(e)
+                exit(2)
+            finally:
+                ssh_cli.close()
+
     def check(self) -> bool:
         pass
 
