@@ -4,13 +4,14 @@ import os
 from redis.sentinel import Sentinel
 from laipvt.model.cmd import DockerImageModel
 from laipvt.model.harbor import HarborModel
-from laipvt.handler.confighandler import CheckResultHandler, ServerHandler, ServiceConfigHandler
+from laipvt.handler.confighandler import CheckResultHandler, ServerHandler
 from laipvt.handler.middlewarehandler import HarborConfigHandler
 from laipvt.sysutil.template import FileTemplate
 from laipvt.sysutil.util import path_join, log, ssh_obj, to_object, walk_sql_path
 from laipvt.handler.middlewarehandler import MiddlewareConfigHandler
 from laipvt.model.cmd import ComposeModel
 from laipvt.model.sql import SqlModule
+from laipvt.model.server import runcmd
 
 
 class ServiceInterface:
@@ -227,19 +228,24 @@ class ServiceInterface:
 
         for cmd in fp.readlines():
             if cmd.strip():
-                remote_cmd = "docker exec -ti rabbitmq {}".format(cmd)
-                self._exec_command_to_host(cmd=remote_cmd, server=self.middleware_servers.get_role_obj("master")[0], check_res=False)
+                log.info(cmd)
+                code, res = runcmd(cmd)
+                if code != 0:
+                    log.error(res)
+                    exit(2)
 
     def init_redis(self):
-        # 连接哨兵服务器
-        pool = []
-        for host in self.middleware_servers.get_role_obj("master"):
-            redis_endpoint = (host.ipaddress, self.middleware_cfg["redis"]["port_sentinel"])
-            pool.append(redis_endpoint)
-        sentinel = Sentinel(pool, socket_timeout=0.5)
-        # 获取主服务器地址
-        master = sentinel.discover_master(self.middleware_cfg.redis.master_name)[0]
-        server_object_list = self.check_result.servers.search_server(key="ipaddress", value=master)
+        if self.middleware_cfg["redis"]["is_deploy"]:
+            # 如果是自建redis服务，连接哨兵服务器，获取master节点地址
+            pool = []
+            for host in self.middleware_servers.get_role_obj("master"):
+                redis_endpoint = (host.ipaddress, self.middleware_cfg["redis"]["port_sentinel"])
+                pool.append(redis_endpoint)
+            sentinel = Sentinel(pool, socket_timeout=0.5)
+            # 获取主服务器地址
+            master_address = sentinel.discover_master(self.middleware_cfg.redis.master_name)[0]
+            # server_object_list = self.check_result.servers.search_server(key="ipaddress", value=master)
+            self.middleware_cfg["redis"]["master_address"] = master_address
 
         log.info("渲染初始化redis脚本: {} -- > {}".format(
             self.redis_init_file_template_path,
@@ -252,8 +258,11 @@ class ServiceInterface:
 
         for cmd in fp.readlines():
             if cmd.strip():
-                remote_cmd = "docker exec md-redis {}".format(cmd)
-                self._exec_command_to_host(cmd=remote_cmd, server=server_object_list[0], check_res=False)
+                log.info(cmd)
+                code, res = runcmd(cmd)
+                if code != 0:
+                    log.error(res)
+                    exit(2)
 
     def init_identity_user(self):
         init_user_cmd = "docker exec ids-server dotnet /opt/tool/idsadmin.dll -a add -u admin -p 123456"
