@@ -2,6 +2,7 @@ from __future__ import absolute_import
 from __future__ import unicode_literals
 
 import os
+import json
 import re
 import string
 import shutil
@@ -260,6 +261,13 @@ def write_to_file(file_name, content=""):
     with open(file_name, "w", encoding="utf-8") as f:
         f.write(content)
 
+def read_form_json_file(file_name):
+    """
+    读取json文件，返回dict
+    """
+    with open(file_name, "r") as fp:
+         return json.load(fp)
+
 def get_value_form_file(file_path, key):
     c = get_yaml_config(file_path)
-    return c.get(key, False)
\ No newline at end of file
+    return c.get(key, False)
